<a id="utils.signals.SignalBlocker"></a>

## SignalBlocker Objects

```python
class SignalBlocker()
```

A context manager that blocks the signals of the provided widget.

The signals are unblocked at the end of the with block.

<a id="utils.signals.SignalBlocker.__init__"></a>

#### \_\_init\_\_

```python
def __init__(widget)
```

<a id="utils.signals.SignalBlocker.__enter__"></a>

#### \_\_enter\_\_

```python
def __enter__()
```

<a id="utils.signals.SignalBlocker.__exit__"></a>

#### \_\_exit\_\_

```python
def __exit__(*_)
```

